@@ -13,6 +13,10 @@
 ## -*- texinfo -*- 
 ## @deftypefn {} {@var{dev} =} i2cdev (@var{ar}, @var{address})
 ## @deftypefnx {} {@var{dev} =} i2cdev (@var{ar}, @var{address}, @var{propname}, @var{propvalue})
+##
+## @code{i2cdev} is depreciated and will be removed in a future version.
+## Use @code{device} instead.
+##
 ## Create an i2cdev object to communicate to the i2c port on a connected arduino.
 ##
 ## @subsubheading Inputs
@@ -51,6 +55,13 @@
 function p = i2cdev(varargin)
   ARDUINO_I2C_CONFIG = 1;
 
+  persistent warned = false;
+  if (! warned)
+    warned = true;
+    warning ("Octave:deprecated-function",
+             "spidev is obsolete and will be removed from a future version of arduino, please use 'device' instead");
+  endif
+ 
   if nargin < 2
     error("expects arduino object and address");
   endif
@@ -143,11 +154,12 @@ endfunction
 %! ar = arduino();
 %! assert(!isempty(ar));
 %! pins = getI2CTerminals(ar);
+%! # TODO check pins unallocated when we have implemented a free of shared spi bus
 %! # check pins not allocated
-%! for i=1:numel(pins)
-%!  p = pins{i};
-%!  assert(configurePin(ar, p), "unset")
-%! endfor
+%! #for i=1:numel(pins)
+%! # p = pins{i};
+%! # assert(configurePin(ar, p), "unset")
+%! #endfor
 %! i2c = i2cdev(ar, 10);
 %! assert(!isempty(i2c));
 %! assert(i2c.address, 10);
@@ -155,7 +167,7 @@ endfunction
 %! # check pins allocated
 %! for i=1:numel(pins)
 %!  p = pins{i};
-%!  assert(!strcmpi(configurePin(ar, p), "unset"))
+%!  assert(strcmpi(configurePin(ar, p), "i2c"))
 %! endfor
 %! clear i2c
 %! # TODO check pins unallocated when we have implemented a free of shared spi bus
